Package: HGC
Type: Package
Title: A fast hierarchical graph-based clustering method
Version: 1.20.0
Authors@R: c(person("Zou", "Ziheng",
                email = "zouzh14@gmail.com",
                role=c("aut")),
             person("Hua", "Kui",
                role=c("aut")),
             person("XGlab",
                email = "xglab@mail.tsinghua.edu.cn",
                role=c("cre", "cph")))
Description: HGC (short for Hierarchical Graph-based Clustering) is an R package for 
        conducting hierarchical clustering on large-scale single-cell RNA-seq 
        (scRNA-seq) data. The key idea is to construct a dendrogram of cells on 
        their shared nearest neighbor (SNN) graph. HGC provides functions for 
        building graphs and for conducting hierarchical clustering on the graph. The
        users with old R version could visit 
        https://github.com/XuegongLab/HGC/tree/HGC4oldRVersion to get HGC package
        built for R 3.6.
License: GPL-3
Encoding: UTF-8
SystemRequirements: C++11
Depends: R (>= 4.1.0)
Imports: Rcpp (>= 1.0.0), RcppEigen(>= 0.3.2.0), Matrix, RANN, ape,
        dendextend, ggplot2, mclust, patchwork, dplyr, grDevices,
        methods, stats
LinkingTo: Rcpp, RcppEigen
Suggests: BiocStyle, rmarkdown, knitr, testthat (>= 3.0.0)
VignetteBuilder: knitr
biocViews: SingleCell, Software, Clustering, RNASeq, GraphAndNetwork,
        DNASeq
Config/testthat/edition: 3
NeedsCompilation: yes
Packaged: 2026-04-28 22:34:47 UTC; biocbuild
git_url: https://git.bioconductor.org/packages/HGC
git_branch: RELEASE_3_23
git_last_commit: 4afcd45
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
Author: Zou Ziheng [aut],
  Hua Kui [aut],
  XGlab [cre, cph]
Maintainer: XGlab <xglab@mail.tsinghua.edu.cn>
