useDynLib(HGC, .registration = TRUE)

export(HGC.dendrogram)
export(HGC.parameter)
export(KNN.Construction)
export(RNN.Construction)
export(CKNN.Construction)
export(SNN.Construction)
export(MST.Construction)
export(PMST.Construction)
export(HGC.PlotDendrogram)
export(HGC.PlotARIs)
export(HGC.PlotParameter)
export(FindClusteringTree)
S3method(HGC.dendrogram, default)
S3method(HGC.dendrogram, dgCMatrix)
S3method(HGC.dendrogram, graph)
S3method(HGC.dendrogram, matrix)
S3method(HGC.dendrogram, igraph)

import(Matrix)
import(Rcpp)
import(RcppEigen)
import(ggplot2)
import(dendextend)
import(dplyr)
importFrom(stats, order.dendrogram)
importFrom(RANN, nn2)
importFrom(ape, mst)
importFrom(grDevices, hcl)
importFrom(mclust, adjustedRandIndex)
importFrom(patchwork, wrap_plots)
importFrom(methods, as)