# The function could record the parameters

    Code
      HGC.dendrogram(G = sim.SNN)
    Output
      
      Call:
      NA
      
      Cluster method   : HGC 
      Distance         : Node pair sampling ratio 
      Number of objects: 100 
      

